Skip to contents

A function mapping a numeric vector to a (presumably sparser) numeric vector of the same shape to be passed onto synthdid_estimate.

Usage

sparsify_function(v)

Arguments

v

a vector