Skip to contents

For our estimator and a placebo, plots treated and synthetic control trajectories and overlays a 2x2 diff-in-diff diagram. Requires ggplot2

Usage

synthdid_placebo_plot(estimate, overlay = FALSE, treated.fraction = NULL)

Arguments

estimate,

as output by synthdid_estimate.

overlay,

binary, indicates whether plots should be overlaid or shown in different facets. Defaults to FALSE.

treated.fraction

as in synthdid_placebo

Value

A ggplot2 object showing the estimate and placebo comparison.

Examples

# \donttest{
data(california_prop99)
setup <- panel.matrices(california_prop99)
tau.hat <- synthdid_estimate(setup$Y, setup$N0, setup$T0)
synthdid_placebo_plot(tau.hat, treated.fraction = 0.5)

# }