Calculate the standard error of a synthetic diff in diff estimate. Deprecated. Use vcov.synthdid_estimate.
Source:R/vcov.R
synthdid_se.RdCalculate the standard error of a synthetic diff in diff estimate. Deprecated. Use vcov.synthdid_estimate.
Examples
# \donttest{
# This function is deprecated. Use sqrt(vcov(...)) instead.
data(california_prop99)
setup <- panel.matrices(california_prop99)
tau.hat <- synthdid_estimate(setup$Y, setup$N0, setup$T0)
# Deprecated approach (still works)
se.old <- synthdid_se(tau.hat, method = "jackknife")
# Preferred approach
se.new <- sqrt(vcov(tau.hat, method = "jackknife"))
# Both give the same result
all.equal(se.old, se.new)
#> [1] TRUE
# }